@@ -1,6 +1,6 @@
 from .bil.bil import Bil
 from .bsq.bsq import Bsq
 from .tif.tif import Tif
-from .flo.flo import Flo
+from .flo.flo import Flo, compute_epe
 from .raster import Raster, read, convolve2d, inpaint_nans
 from ._ext import *
